"""
2021.5.20 create by kefeng.zheng
银行卡分期接口调用实例
"""
import sys

import os

# 得到当前根目录
o_path = os.getcwd() # 返回当前工作目录
sys.path.append(o_path) # 添加当前目录，当前目录为basepay_demo的上一级时可导入basepay_sdk
sys.path.append('..') # 添加上一级目录，当前目录为basepay_demo下时，可导入basepay_sdk

from basepay_sdk.basepay_client import BasePayClient
from basepay_sdk.basepay import BasePay

import logging
import json
import datetime
import time

# 商户配置初始化
from demo_constants import demo_constants
import init_merchant_config

# 调试模式，默认False关闭，打开后输出日志供联调排查问题
BasePay.debug = True
# 生产模式，默认为True生产环境
BasePay.prod_mode = True

# 分期签约参数组装
req_date_sign = datetime.datetime.now().strftime('%Y%m%d')
now_datetime_sign = datetime.datetime.now().strftime('%Y%m%d%H%M%S')
req_seq_id_sign = now_datetime_sign + "01234567890"
request_param_sign = {
    # 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
    "req_seq_id" : req_seq_id_sign,
    # 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
    "req_date": req_date_sign,
    # 系统号，由汇付分配
    "sys_id": demo_constants.DEMO_SYS_ID,
    # 分配商户号
    "huifu_id": demo_constants.DEMO_HUIFU_ID,
    # 银行编号
    "bank_no" : "03050000",
    # 持卡人姓名
    "card_name":"张三",
    # 银行卡号
    "card_no":"6226888896666124",
    # 银行卡手机号
    "card_mobile":"17688886666",
    # 证件类型  01：身份证
    "id_type":"01",
    # 证件号
    "id_no":"230404197008080666",
	# CVV2
    "cvv2" : '666',
	# 有效期
    "valid_date" : '0325',
	# 卡类型 D:借记卡 C:信用卡 P:存折 Y:预付费卡 V:虚拟账户 Z:借贷合一卡
    "card_type" : 'C',
	# 银行账户类型 E：对公，P：对私
    "card_acct_type" : 'P',
	# 交易金额 单位元，需保留小数点后两位
    "trans_amt" : '100.00',
    # 设备信息
    "terminal_device_info": {
            "device_type":"4",
            "device_ip":"139.207.19.246"
     },
    
    # 异步通知地址
    "notify_url":"virgo://http://www.vclinker.com",

    # 页面跳转地址(支付成功后，前端跳转地址)
    "business_url":"http://www.baidu.com",
    # 请求类型 0:pc 1:安卓 2：ios
    "request_type":"0",
    # 业务地址 6位地区编码
    "place_id":"200000"
}

# 调用分期签约接口
try:
	post_result = BasePayClient.post_request('top.bccredit.sign', request_param_sign)
	# 如果需要套用指定配置调用接口，请参考以下
	# post_result = BasePayClient.post_request('top.bccredit.sign', request_param_sign, 'merchantKey2')
except Exception as e:
	print(str(e))
	sys.exit()

sub_resp_code = post_result.get('sub_resp_code', '')

if (sub_resp_code == '00000000'):
	print('分期签约处理成功')
	print('交易状态：' + post_result.get('trans_stat', ''))
	
elif (sub_resp_code == '00000100'):
	print('分期签约处理中')
	print('交易状态：' + post_result.get('trans_stat', ''))
	
else:
	print ('分期签约处理失败:' + post_result.get('sub_resp_desc', ''))
	
time.sleep(30) # 休眠30秒



# 银行卡分期支付请求 参数组装
req_date_pay = datetime.datetime.now().strftime('%Y%m%d')
now_datetime_pay = datetime.datetime.now().strftime('%Y%m%d%H%M%S')
req_seq_id_pay = now_datetime_pay + "01234567890"
mer_ord_id_pay = now_datetime_pay + "01234";
time_expire = (datetime.datetime.now() + datetime.timedelta(minutes=2)).strftime('%Y%m%d%H%M%S')
request_param_pay = {
    # 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
    "req_seq_id" : req_seq_id_pay,
    # 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
    "req_date": req_date_pay,
    # 系统号，由汇付分配
    "sys_id": demo_constants.DEMO_SYS_ID,
    # 商户订单号，需保证商户下唯一，推荐采用日期时间+几位流水号的形式，可与req_seq_id相同
    "mer_ord_id": mer_ord_id_pay,
    # 分配商户号
    "huifu_id": demo_constants.DEMO_HUIFU_ID,
    # 银行编号
    "bank_no" : "03050000",
    # 持卡人姓名
    "card_name":"张三",
    # 银行卡号
    "card_no":"6226888896666124",
    # 银行卡手机号
    "card_mobile":"17688886666",
    # 证件类型  01：身份证
    "id_type":"01",
    # 证件号
    "id_no":"230404197008080666",
	# CVV2
    "cvv2" : '666',
	# 有效期
    "valid_date" : '0325',
	# 卡类型 D:借记卡 C:信用卡 P:存折 Y:预付费卡 V:虚拟账户 Z:借贷合一卡
    "card_type" : 'C',
	# 银行账户类型 E：对公，P：对私
    "card_acct_type" : 'P',
	# 交易金额 单位元，需保留小数点后两位
    "trans_amt" : '100.00',
	# 手续费收取方式 1-实收 2-后收
    "fee_rec_type" : '2',
    # 设备信息
    "terminal_device_info": {
            "device_type":"4",
            "device_ip":"139.207.19.246"
     },
    # 网联扩展字段
    "risk_check_info" : {
        "pyee_acct_id" : "6214***************6688",
        "pyee_nm" : "李四",
        "pyee_acct_tp" : "04",
        "mer_type" : "02",
        "mer_id_type" : "00",
        "mer_id_no" : "310528198006088686",
        "mer_cat_code" : "8541",
        "goods_short_name" : "*********",
        "biz_tp" : "100001"
    },
    # 风控信息
    # 注意，风控信息为JSON字符串
    "risk_check_info" : json.dumps({
        "riskMngInfo" : {
            "subTradeType" : "4300"
        },
        "ipAddr":"139.207.19.246"
    }),
    # 异步通知地址
    "notify_url":"virgo://http://www.vclinker.com",

    # 分期期数 3 6 12 24
    "instalments_num":"3",
    # 延时标志 1为延迟 0为不延迟
    "is_delay_acct":"0",
    # 传入分帐遇到优惠的处理规则 1-按比例分 2-按顺序保障 3-只给交易商户
    "term_div_coupon_type":"3",
    # 分账串
    # 注意只有真实分账场景才需要传入分账串，请避免传入多个分账方为同一商户的分账串
#    "acct_split_bunch":{
#        "acct_infos" : [
#            # 分账方1
#            {
#                'huifu_id':demo_constants.DEMO_HUIFU_ID,
#                'div_amt':'0.01'
#            },
#            # 分账方2
#            {
#                "huifu_id":demo_constants.DEMO_DIV_HUIFU_ID,
#                "div_amt":"0.01"
#            }
#        ]
#    }
}

# 调用分期支付请求接口
try:
	post_result = BasePayClient.post_request('top.bccredit.paymentApply', request_param_pay)
	# 如果需要套用指定配置调用接口，请参考以下
	# post_result = BasePayClient.post_request('top.bccredit.paymentApply', request_param_pay, 'merchantKey2')
except Exception as e:
	print(str(e))
	sys.exit()

sub_resp_code = post_result.get('sub_resp_code', '')

if (sub_resp_code == '00000000'):
	print('分期支付请求处理成功')
	print('交易状态：' + post_result.get('trans_stat', ''))
elif (sub_resp_code == '00000100'):
	print('分期支付请求处理中')
	print('交易状态：' + post_result.get('trans_stat', ''))
else:
	print ('分期支付请求处理失败:' + post_result.get('sub_resp_desc', ''))
	
time.sleep(30) # 休眠30秒






# 银行卡分期支付确认 参数组装
req_date_confirm = datetime.datetime.now().strftime('%Y%m%d')
now_datetime_confirm = datetime.datetime.now().strftime('%Y%m%d%H%M%S')
req_seq_id_confirm = now_datetime_confirm + "01234567890"
mer_ord_id_confirm = now_datetime_confirm + "01234";
request_param_confirm = {
    # 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
    "req_seq_id" : req_seq_id_confirm,
    # 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
    "req_date": req_date_confirm,
    # 系统号，由汇付分配
    "sys_id": demo_constants.DEMO_SYS_ID,
    # 商户订单号，需保证商户下唯一，推荐采用日期时间+几位流水号的形式，可与req_seq_id相同
    "mer_ord_id": mer_ord_id_confirm,
    # 分配商户号
    "huifu_id": demo_constants.DEMO_HUIFU_ID,
    # 原请求流水号
    "org_seq_id" : req_seq_id_pay,
    # 原请求时间
    "org_seq_date" : req_date_pay,
    
	# CVV2
    "cvv2" : '666',
	# 有效期
    "valid_date" : '0325',
	# 手机验证码
    "verify_code" : '123456',
    # 设备信息
    "terminal_device_info": {
            "device_type":"4",
            "device_ip":"139.207.19.246"
     },
    # 网联扩展字段
    "risk_check_info" : {
        "pyee_acct_id" : "6214***************6688",
        "pyee_nm" : "李四",
        "pyee_acct_tp" : "04",
        "mer_type" : "02",
        "mer_id_type" : "00",
        "mer_id_no" : "310528198006088686",
        "mer_cat_code" : "8541",
        "goods_short_name" : "*********",
        "biz_tp" : "100001"
    },
    # 风控信息
    # 注意，风控信息为JSON字符串
    "risk_check_info" : json.dumps({
        "riskMngInfo" : {
            "subTradeType" : "4300"
        },
        "ipAddr":"139.207.19.246"
    }),
    # 异步通知地址
    "notify_url":"virgo://http://www.vclinker.com",

}

# 调用分期支付确认接口
try:
	post_result = BasePayClient.post_request('top.bccredit.paymentConfirm', request_param_confirm)
	# 如果需要套用指定配置调用接口，请参考以下
	# post_result = BasePayClient.post_request('top.bccredit.paymentConfirm', request_param_confirm, 'merchantKey2')
except Exception as e:
	print(str(e))
	sys.exit()

sub_resp_code = post_result.get('sub_resp_code', '')

if (sub_resp_code == '00000000'):
	print('分期支付确认处理成功')
	print('交易状态：' + post_result.get('trans_stat', ''))
elif (sub_resp_code == '00000100'):
	print('分期支付确认处理中')
	print('交易状态：' + post_result.get('trans_stat', ''))
else:
	print ('分期支付确认处理失败:' + post_result.get('sub_resp_desc', ''))
	
time.sleep(30) # 休眠30秒




# 银行卡分期交易查询 参数组装
request_param_query = {
	'sys_id' : demo_constants.DEMO_SYS_ID,
	'huifu_id' : demo_constants.DEMO_HUIFU_ID,
    # 原始请求日期
	'req_date' : req_date_confirm,
    # 原始请求流水号 只能上送银行卡分期确认交易的流水号req_seq_id和hf_seq_id二选一
	'req_seq_id' : req_seq_id_confirm
}
# 调用银行卡分期交易查询接口
try:
	query_result = BasePayClient.post_request('topqur.bcCreditPayQuery', request_param_query)
	# 如果需要套用指定配置调用接口，请参考以下
	# query_result = BasePayClient.post_request('topqur.bcCreditPayQuery', request_param_query, 'merchantKey2')
except Exception as e:
	print(str(e))
	sys.exit()
	
sub_resp_code = query_result.get('sub_resp_code', '')

if (sub_resp_code == '00000000'):
	print('分期交易查询处理成功')
	print('交易状态：' + query_result.get('trans_stat', ''))
elif (sub_resp_code == '00000100'):
	print('分期交易查询处理中')
	print('交易状态：' + query_result.get('trans_stat', ''))
else:
	print ('分期交易查询处理失败:' + query_result.get('sub_resp_desc', ''))


# 银行卡分期退款
req_date_refund = datetime.datetime.now().strftime('%Y%m%d')
now_datetime_refund = datetime.datetime.now().strftime('%Y%m%d%H%M%S')
req_seq_id_refund = now_datetime_refund + "01234567890R"
mer_ord_id_refund = now_datetime_refund + "01234";
request_params_refund = {
	'req_date' : req_date_refund,
	'req_seq_id' : req_seq_id_refund,
	'mer_ord_id' : mer_ord_id_refund,
	'sys_id' : demo_constants.DEMO_SYS_ID,
	'huifu_id' : demo_constants.DEMO_HUIFU_ID,
	#分账串，原路径退回无需上送
	#"acct_split_bunch":{
	#"acct_infos" : [
	#	# 分账方1
	#	{
	#		'huifu_id':demo_constants.DEMO_HUIFU_ID,
	#		'div_amt':'0.01'
	#	},
	#	# 分账方2
	#	{
	#		"huifu_id":demo_constants.DEMO_DIV_HUIFU_ID,
	#		"div_amt":"0.01"
	#	}
	#]
	#},
	# 原交易日期
	'org_req_date' : req_date_pay,
	# 以下指定原交易的唯一标识，org_req_seq_id、hf_seq_id、party_order_id中3选1
	# 原交易请求流水号
	'org_req_seq_id' : req_seq_id_pay,
	# 退款金额 单位元，需保留小数点后两位，例如： 1.00
	'ord_amt' : '100.00',
	# 设备信息
	"terminal_device_info": {
		"device_type":"4",
		"device_ip":"139.207.19.246"
	},
	# 备注
	'mark' : '交易退货测试',
	# 风控信息
	# 注意，风控信息为JSON字符串
	"risk_check_info" : {
		"riskMngInfo" : {
			"subTradeType" : "4300"
		},
		"ipAddr":"139.207.19.246"
	},
	# 异步通知地址
	"notify_url":"virgo://http://www.vclinker.com"
}

# 调用交易退款接口
try:
	refund_result = BasePayClient.post_request('toprrc.bccredit.refund', request_params_refund)
	# 如果需要套用指定配置调用接口，请参考以下
	# refund_result = BasePayClient.post_request('toprrc.bccredit.refund', request_params_refund, 'merchantKey2')
except Exception as e:
	print(str(e))
	sys.exit()
	
sub_resp_code = refund_result.get('sub_resp_code', '')

if (sub_resp_code == '00000000'):
	print('分期退款处理成功')
	print('交易状态：' + refund_result.get('trans_stat', ''))
elif (sub_resp_code == '00000100'):
	print('分期退款处理中')
	print('交易状态：' + refund_result.get('trans_stat', ''))
else:
	print ('分期退款处理失败:' + refund_result.get('sub_resp_desc', ''))
	
