"""
2021.5.26 create by jili.hua
线上交易类接口调用实例
"""
import sys

import os

# 得到当前根目录
o_path = os.getcwd()  # 返回当前工作目录
sys.path.append(o_path)  # 添加当前目录，当前目录为basepay_demo的上一级时可导入basepay_sdk
sys.path.append('..')  # 添加上一级目录，当前目录为basepay_demo下时，可导入basepay_sdk

from basepay_sdk.basepay_client import BasePayClient
from basepay_sdk.basepay import BasePay

import logging
import json
import datetime
import time

# 商户配置初始化
from demo_constants import demo_constants
import init_merchant_config

# 调试模式，默认False关闭，打开后输出日志供联调排查问题
BasePay.debug = True
# 生产模式，默认为True生产环境
BasePay.prod_mode = True

req_date = datetime.datetime.now().strftime('%Y%m%d')
now_datetime = datetime.datetime.now().strftime('%Y%m%d%H%M%S')
req_seq_id = now_datetime + "01234567890"
# mer_ord_id = now_datetime + "1234567890"
mer_ord_id = req_seq_id;
time_expire = (datetime.datetime.now() + datetime.timedelta(minutes=2)).strftime('%Y%m%d%H%M%S')
request_param = {
    # 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
    "req_seq_id": req_seq_id,
    # 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
    "req_date": req_date,
    # 分配商户号
    "huifu_id": demo_constants.DEMO_HUIFU_ID,
    # 银行卡号
    "card_no": "6226********0124",
    # 交易金额
    "trans_amt": "200.00",
    # 异步通知地址
    "mer_notice_url": "virgo://http://www.vclinker.com",
    # 页面跳转地址
    "business_url": "http://www.xxx.com/getResp",
    # 失败页面跳转地址
    "business_fail_url": "http://www.xxx.com/getFailResp",
    # 交易有效期
    "time_expire": time_expire,
    # 网联扩展信息
    # 01:电脑，02:手机，03:平板设备，04:可穿戴设备，05数字电视，06条码支付受理终端，99其他
    "extend_pay": json.dumps({
        "pyer_trx_trm_tp": "02"
    }),

    # 设备信息
    "device_info": json.dumps({
        # 01:手机，02:平板，03:手表，04:PC
        "trx_device_type": "01",
        "trx_device_ip": "139.207.19.246"
    }),
    # 风控信息
    # 注意，风控信息为JSON字符串
    "risk_check_info": json.dumps({
        "riskMngInfo": {
            "subTradeType": "4300"
        },
        "ipAddr": "139.207.19.246"
    }),
    # 分账串
    # 注意只有真实分账场景才需要传入分账串，请避免传入多个分账方为同一商户的分账串
    "acct_split_bunch": {
        "acct_infos": [
            # 分账方1
            {
                'huifu_id': demo_constants.DEMO_HUIFU_ID,
                'div_amt': '100.00'
            },
            # 分账方2
            {
                "huifu_id": demo_constants.DEMO_DIV_HUIFU_ID,
                "div_amt": "100.00"
            }
        ]
    },
}

# 调用手机网页支付接口
try:
    post_result = BasePayClient.post_request('top-online-ser.wapPay', request_param)
# 如果需要套用指定配置调用接口，请参考以下
# post_result = BasePayClient.post_request('top-online-ser.wapPay', request_param, 'merchantKey2')
except Exception as e:
    print(str(e))
    sys.exit()

sub_resp_code = post_result.get('sub_resp_code', '')

if sub_resp_code == '00000000':
    print('处理成功')
    print('交易状态：' + post_result.get('trans_stat', ''))
# 交易状态处理中后续可调用交易查询接口获取终态
elif sub_resp_code == '00000100':
    print('处理中')
    print('银行提交页面html：' + post_result.get('form_html', ''))
    print('页面字符集：' + post_result.get('form_encoding', ''))
# 交易状态处理中后续可调用交易查询接口获取终态
else:
    print('处理失败:' + post_result.get('sub_resp_desc', ''))

time.sleep(30)  # 休眠30秒

# 线上交易查询参数组装
query_params = {
    'product_id': post_result.get('product_id', ''),
    'req_date': request_param.get('req_date', ''),
    'req_seq_id': request_param.get('req_seq_id', ''),
    'huifu_id': request_param.get('huifu_id', '')
}
# 调用交易查询接口
try:
    query_result = BasePayClient.post_request('top-online-ser.transQuery', query_params)
# 如果需要套用指定配置调用接口，请参考以下
# query_result = BasePayClient.post_request('top-online-ser.transQuery', query_params, 'merchantKey2')
except Exception as e:
    print(str(e))
    sys.exit()

sub_resp_code = query_result.get('sub_resp_code', '')

if sub_resp_code == '00000000':
    print('交易查询处理成功')
    print('交易状态：' + query_result.get('trans_stat', ''))
else:
    print('查询处理失败:' + query_result.get('sub_resp_desc', ''))

now_datetime = datetime.datetime.now().strftime('%Y%m%d%H%M%S')
req_seq_id = now_datetime + "01234567890R"
mer_ord_id = req_seq_id;
refund_params = {
    'req_date': req_date,
    'req_seq_id': req_seq_id,
    'mer_ord_id': mer_ord_id,
    'sys_id': request_param.get('sys_id', ''),
    'huifu_id': request_param.get('huifu_id', ''),
    # 分账串，原路径退回无需上送
    # "acct_split_bunch":{
    # "acct_infos" : [
    #	# 分账方1
    #	{
    #		'huifu_id':demo_constants.DEMO_HUIFU_ID,
    #		'div_amt':'0.01'
    #	},
    #	# 分账方2
    #	{
    #		"huifu_id":demo_constants.DEMO_DIV_HUIFU_ID,
    #		"div_amt":"0.01"
    #	}
    # ]
    # },
    # 原交易日期
    'org_req_date': request_param.get('req_date', ''),
    # 以下指定原交易的唯一标识，org_req_seq_id、hf_seq_id、party_order_id中3选1
    # 原交易请求流水号
    'org_req_seq_id': request_param.get('req_seq_id', ''),
    # 退款金额
    'ord_amt': '0.02',
    # 设备信息
    "device_info": {
        "trx_device_type": "04",
        "trx_device_ip": "139.207.19.246"
    },
    # 风控信息
    # 注意，风控信息为JSON字符串
    "risk_check_info": json.dumps({
        "riskMngInfo": {
            "subTradeType": "4300"
        },
        "ipAddr": "139.207.19.246"
    }),
    # 异步通知地址
    "notify_url": "virgo://http://www.vclinker.com"
}

# 调用线上交易退款接口
try:
    refund_result = BasePayClient.post_request('top-online-ser.refund', refund_params)
# 如果需要套用指定配置调用接口，请参考以下
# refund_result = BasePayClient.post_request('top-online-ser.refund', refund_params, 'merchantKey2')
except Exception as e:
    print(str(e))
    sys.exit()

sub_resp_code = refund_result.get('sub_resp_code', '')

if sub_resp_code == '00000000':
    print('退款处理成功')
    print('交易状态：' + refund_result.get('trans_stat', ''))
elif sub_resp_code == '00000100':
    print('退款处理中')
    print('交易状态：' + refund_result.get('trans_stat', ''))
else:
    print('退款处理失败:' + refund_result.get('sub_resp_desc', ''))

# 线上退款查询参数组装
refund_query_params = {
    # 系统号
    'sys_id': refund_params.get('sys_id', ''),
    # 退款商户号
    'huifu_id': refund_result.get('huifu_id', ''),
    # 原始退款请求日期
    'req_date': refund_result.get('req_date', ''),
    # 原退款请求流水号
    'req_seq_id': refund_result.get('req_seq_id', '')
}

# 调用交易退款查询接口
try:
    refund_query_result = BasePayClient.post_request('top-online-ser.refundQuery', refund_query_params)
# 如果需要套用指定配置调用接口，请参考以下
# refund_query_result = BasePayClient.post_request('top-online-ser.refundQuery', refund_query_params, 'merchantKey2')
except Exception as e:
    print(str(e))
    sys.exit()

sub_resp_code = refund_query_result.get('sub_resp_code', '')

if sub_resp_code == '00000000':
    print('退款查询处理成功')
    print('交易状态：' + refund_query_result.get('trans_stat', ''))
else:
    print('退款查询处理失败:' + refund_query_result.get('sub_resp_desc', ''))

# 交易确认调用实例
req_seq_id = now_datetime + "01234567890A"
mer_ord_id = req_seq_id;
pay_confirm_params = {
    # 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
    "req_date": req_date,
    # 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
    "req_seq_id": req_seq_id,
    # 商户号
    "huifu_id": demo_constants.DEMO_HUIFU_ID,
    # 分配系统号
    "sys_id": demo_constants.DEMO_SYS_ID,
    # 商户订单号
    "mer_ord_id": mer_ord_id,
    # 原交易请求流水号
    "org_req_seq_id": "2021042214110401234567890",
    # 原交易请求日期
    "org_req_date": "20210422",
    # 分账串
    # 注意只有真实分账场景才需要传入分账串，请避免传入多个分账方为同一商户的分账串
    "acct_split_bunch": {
        "acct_infos": [
            # 分账方1
            {
                'huifu_id': demo_constants.DEMO_HUIFU_ID,
                'div_amt': '0.01'
            },
            # 分账方2
            {
                "huifu_id": demo_constants.DEMO_DIV_HUIFU_ID,
                "div_amt": "0.01"
            }
        ]
    },
}

# 调用交易确认
try:
    pay_confirm_result = BasePayClient.post_request('topat.payConfirm', pay_confirm_params)
# 如果需要套用指定配置调用接口，请参考以下
# pay_confirm_result = BasePayClient.post_request('topat.payConfirm', pay_confirm_params, 'merchantKey2')
except Exception as e:
    print(str(e))
    sys.exit()

sub_resp_code = pay_confirm_result.get('sub_resp_code', '')

if sub_resp_code == '00000000':
    print('交易确认处理成功')
else:
    print('交易确认处理失败:' + pay_confirm_result.get('sub_resp_desc', ''))


# 交易确认查询调用实例
confirm_query_params = {
    'product_id': pay_confirm_result.get('product_id', ''),
    'req_date': pay_confirm_result.get('req_date', ''),
    'req_seq_id': pay_confirm_result.get('req_seq_id', ''),
    'huifu_id': pay_confirm_result.get('huifu_id', '')
}
# 调用交易确认查询接口
try:
    query_result = BasePayClient.post_request('topqur.payConfirmQuery', confirm_query_params)
# 如果需要套用指定配置调用接口，请参考以下
# query_result = BasePayClient.post_request('topqur.payConfirmQuery', confirm_query_params, 'merchantKey2')
except Exception as e:
    print(str(e))
    sys.exit()

sub_resp_code = query_result.get('sub_resp_code', '')

if sub_resp_code == '00000000':
    print('交易查询处理成功')
    print('交易状态：' + query_result.get('trans_stat', ''))
else:
    print('查询处理失败:' + query_result.get('sub_resp_desc', ''))

# 交易确认退款调用实例
req_seq_id = now_datetime + "01234567890A"
mer_ord_id = req_seq_id;
pay_confirm_refund_params = {
    # 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
    "req_date": req_date,
    # 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
    "req_seq_id": req_seq_id,
    # 商户号
    "huifu_id": demo_constants.DEMO_HUIFU_ID,
    # 分配系统号
    "sys_id": demo_constants.DEMO_SYS_ID,
    # 商户订单号
    "mer_ord_id": mer_ord_id,
    # 原交易请求流水号
    "org_req_seq_id": pay_confirm_result.get('req_seq_id', ''),
    # 原交易请求日期
    "org_req_date": pay_confirm_result.get('req_date', ''),
    # 分账串
    # 注意只有真实分账场景才需要传入分账串，请避免传入多个分账方为同一商户的分账串
    "acct_split_bunch": {
        "acct_infos": [
            # 分账方1
            {
                'huifu_id': demo_constants.DEMO_HUIFU_ID,
                'div_amt': '0.01'
            },
            # 分账方2
            {
                "huifu_id": demo_constants.DEMO_DIV_HUIFU_ID,
                "div_amt": "0.01"
            }
        ]
    },
}

# 调用交易确认退款
try:
    pay_confirm_refund_result = BasePayClient.post_request('toprrc.payConfirmRefund', pay_confirm_refund_params)
# 如果需要套用指定配置调用接口，请参考以下
# pay_confirm_refund_result = BasePayClient.post_request('toprrc.payConfirmRefund', pay_confirm_refund_params, 'merchantKey2')
except Exception as e:
    print(str(e))
    sys.exit()

sub_resp_code = pay_confirm_refund_result.get('sub_resp_code', '')

if sub_resp_code == '00000000':
    print('交易确认退款处理成功')
else:
    print('交易确认退款处理失败:' + pay_confirm_refund_result.get('sub_resp_desc', ''))

# 调用交易确认批量查询接口
confirm_list_query_params = {
    'trans_req_date': "20210422",
    'trans_req_seq_id': "2021042214110401234567890",
    'huifu_id': pay_confirm_result.get('huifu_id', '')
}
# 调用交易确认批量查询接口
try:
    query_result = BasePayClient.post_request('topqur.payConfirmListQuery', confirm_list_query_params)
# 如果需要套用指定配置调用接口，请参考以下
# query_result = BasePayClient.post_request('topqur.payConfirmListQuery', confirm_list_query_params, 'merchantKey2')
except Exception as e:
    print(str(e))
    sys.exit()

sub_resp_code = query_result.get('sub_resp_code', '')

if sub_resp_code == '00000000':
    print('交易确认批量查询处理成功')
else:
    print('交易确认批量查询处理失败:' + query_result.get('sub_resp_desc', ''))

# 余额支付
req_seq_id = now_datetime + "01234567890AP"
balance_pay_params = {
    # 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
    "req_date": req_date,
    # 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
    "req_seq_id": req_seq_id,
    # 商户号
    "huifu_id": demo_constants.DEMO_HUIFU_ID,
    # 出款商户号
    "out_huifu_id": demo_constants.DEMO_HUIFU_ID,
    # 订单金额
    "ord_amt": "0.02",
    # 设备信息
    "device_info": json.dumps({
        # 1:手机2:平板3:手表4:PC
        "device_type": "1",
        "device_ip": "139.207.19.246"
    }),
    # 风控信息
    # 注意，风控信息为JSON字符串
    "risk_check_info": json.dumps({
        "transferType": "余额支付"
    }),
    # 分账串
    # 注意只有真实分账场景才需要传入分账串，请避免传入多个分账方为同一商户的分账串
    "acct_payment_split_bunch": {
        "acct_infos": [
            # 分账方1
            {
                'in_huifu_id': demo_constants.DEMO_HUIFU_ID,
                'div_amt': '0.01'
            },
            # 分账方2
            {
                "in_huifu_id": demo_constants.DEMO_DIV_HUIFU_ID,
                "div_amt": "0.01"
            }
        ]
    },
}

# 调用余额支付
try:
    balance_pay_result = BasePayClient.post_request('topat.acctPayment', balance_pay_params)
# 如果需要套用指定配置调用接口，请参考以下
# balance_pay_result = BasePayClient.post_request('topat.acctPayment', balance_pay_params, 'merchantKey2')
except Exception as e:
    print(str(e))
    sys.exit()

sub_resp_code = balance_pay_result.get('sub_resp_code', '')

if sub_resp_code == '00000000':
    print('余额支付处理成功')
else:
    print('余额支付处理失败:' + balance_pay_result.get('sub_resp_desc', ''))

# 余额支付查询
acct_query_params = {
    'org_req_date': balance_pay_result.get('req_date', ''),
    'org_req_seq_id': balance_pay_result.get('req_seq_id', ''),
    'huifu_id': balance_pay_result.get('huifu_id', '')
}
# 调用余额支付查询接口
try:
    query_result = BasePayClient.post_request('topat.acctPaymentQuery', acct_query_params)
# 如果需要套用指定配置调用接口，请参考以下
# query_result = BasePayClient.post_request('topat.acctPaymentQuery', acct_query_params, 'merchantKey2')
except Exception as e:
    print(str(e))
    sys.exit()

sub_resp_code = query_result.get('sub_resp_code', '')

if sub_resp_code == '00000000':
    print('余额支付查询处理成功')
    print('交易状态：' + query_result.get('trans_stat', ''))
else:
    print('余额支付处理失败:' + query_result.get('sub_resp_desc', ''))

# 调用余额支付退款
req_seq_id = now_datetime + "01234567890AR"
acct_refund_params = {
    # 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
    "req_date": req_date,
    # 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
    "req_seq_id": req_seq_id,
    # 商户号
    "huifu_id": demo_constants.DEMO_HUIFU_ID,
    # 原交易请求流水号
    "org_req_seq_id": balance_pay_result.get('req_seq_id', ''),
    # 原交易请求时间
    "org_req_date": balance_pay_result.get('req_date', ''),
    # 订单金额
    "ord_amt": "0.02",
    # 风控信息
    # 注意，风控信息为JSON字符串
    "risk_check_info": json.dumps({
        "transferType": "余额支付"
    }),
    # 分账串
    # 注意只有真实分账场景才需要传入分账串，请避免传入多个分账方为同一商户的分账串
    "acct_payment_split_bunch": {
        "acct_infos": [
            # 分账方1
            {
                'in_huifu_id': demo_constants.DEMO_HUIFU_ID,
                'div_amt': '0.01'
            },
            # 分账方2
            {
                "in_huifu_id": demo_constants.DEMO_DIV_HUIFU_ID,
                "div_amt": "0.01"
            }
        ]
    },
}

# 调用余额支付退款
try:
    acct_refund_result = BasePayClient.post_request('topat.acctPayment', acct_refund_params)
# 如果需要套用指定配置调用接口，请参考以下
# acct_refund_result = BasePayClient.post_request('topat.acctPayment', acct_refund_params, 'merchantKey2')
except Exception as e:
    print(str(e))
    sys.exit()

sub_resp_code = acct_refund_result.get('sub_resp_code', '')

if sub_resp_code == '00000000':
    print('余额支付退款处理成功')
else:
    print('余额支付退款处理失败:' + acct_refund_result.get('sub_resp_desc', ''))


# 余额支付退款查询
acct_refund_query_params = {
    'req_date': acct_refund_result.get('req_date', ''),
    'req_seq_id': acct_refund_result.get('req_seq_id', ''),
    'huifu_id': acct_refund_result.get('huifu_id', '')
}
# 调用余额支付退款查询接口
try:
    query_result = BasePayClient.post_request('topat.acctPaymentRefundQuery', acct_refund_query_params)
# 如果需要套用指定配置调用接口，请参考以下
# query_result = BasePayClient.post_request('topat.acctPaymentRefundQuery', acct_refund_query_params, 'merchantKey2')
except Exception as e:
    print(str(e))
    sys.exit()

sub_resp_code = query_result.get('sub_resp_code', '')
if sub_resp_code == '00000000':
    print('余额支付退款查询处理成功')
    print('交易状态：' + query_result.get('trans_stat', ''))
else:
    print('余额支付退款查询处理失败:' + query_result.get('sub_resp_desc', ''))

# 钱包取现
req_seq_id = now_datetime + "01234567890WE"
wallet_enchash_params = {
    # 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
    "req_date": req_date,
    # 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
    "req_seq_id": req_seq_id,
    # 产品号
    "product_id": demo_constants.DEMO_PRODUCT_ID,
    # 系统号
    "sys_id": demo_constants.DEMO_SYS_ID,
    # 商户号
    "huifu_id": demo_constants.DEMO_HUIFU_ID,
    # 取现卡序列号
    "token_no": "5252255",
    # 入账类型 D0:当日到账;T1:下个工作日到账;D1:下个自然日到账
    "into_acct_date_type": "D0",
    # 取现金额
    "cash_amt": "1.00",
    # 异步通知地址
    "notify_url": "virgo://http://www.vclinker.com",
}

# 调用钱包取现
try:
    wallet_enchash_result = BasePayClient.post_request('ssproxy.walletEnchashment', wallet_enchash_params)
# 如果需要套用指定配置调用接口，请参考以下
# wallet_enchash_result = BasePayClient.post_request('ssproxy.walletEnchashment', wallet_enchash_params, 'merchantKey2')
except Exception as e:
    print(str(e))
    sys.exit()
sub_resp_code = wallet_enchash_result.get('sub_resp_code', '')
if sub_resp_code == '00000000':
    print('钱包取现处理成功')
else:
    print('钱包取现处理失败:' + wallet_enchash_result.get('sub_resp_desc', ''))


# 钱包取现查询
req_seq_id = now_datetime + "01234567890WEQ"
wallet_enchash_query_params = {
    # 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
    "req_date": req_date,
    # 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
    "req_seq_id": req_seq_id,
    # 产品号
    "product_id": demo_constants.DEMO_PRODUCT_ID,
    # 商户号
    "huifu_id": demo_constants.DEMO_HUIFU_ID,
    # 原取现交易系统号
    "org_sys_id": demo_constants.DEMO_SYS_ID,
    # 原取现交易请求流水号
    "org_req_seq_id": wallet_enchash_result.get('req_seq_id', ''),
    # 原取现交易请求日期
    "org_req_date": wallet_enchash_result.get('req_date', ''),
}

# 调用钱包取现查询
try:
    wallet_enchash_query_result = BasePayClient.post_request('ssproxy.walletEnchashmentQuery', wallet_enchash_query_params)
# 如果需要套用指定配置调用接口，请参考以下
# wallet_enchash_query_result = BasePayClient.post_request('ssproxy.walletEnchashmentQuery', wallet_enchash_query_params, 'merchantKey2')
except Exception as e:
    print(str(e))
    sys.exit()
sub_resp_code = wallet_enchash_query_result.get('sub_resp_code', '')
if sub_resp_code == '00000000':
    print('钱包取现处理成功')
else:
    print('钱包取现处理失败:' + wallet_enchash_query_result.get('sub_resp_desc', ''))


# 钱包余额冻结
req_seq_id = now_datetime + "01234567890FZ"
wallet_frz_params = {
    # 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
    "req_date": req_date,
    # 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
    "req_seq_id": req_seq_id,
    # 商户号
    "huifu_id": demo_constants.DEMO_HUIFU_ID,
    # 冻结金额
    "trans_amt": "0.01",
}

# 调用钱包余额冻结
try:
    wallet_frz_result = BasePayClient.post_request('ssproxy.frzWalletBal', wallet_frz_params)
# 如果需要套用指定配置调用接口，请参考以下
# wallet_frz_result = BasePayClient.post_request('ssproxy.frzWalletBal', wallet_frz_params, 'merchantKey2')
except Exception as e:
    print(str(e))
    sys.exit()
sub_resp_code = wallet_frz_result.get('sub_resp_code', '')
if sub_resp_code == '00000000':
    print('钱包余额冻结处理成功')
else:
    print('钱包余额冻结处理失败:' + wallet_frz_result.get('sub_resp_desc', ''))

# 钱包余额解冻
req_seq_id = now_datetime + "01234567890UFZ"
wallet_unfrz_params = {
    # 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
    "req_date": req_date,
    # 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
    "req_seq_id": req_seq_id,
    # 商户号
    "huifu_id": demo_constants.DEMO_HUIFU_ID,
    # 解冻明细列表
    "un_frz_infos": [
            # 仅支持一条
            {
                'org_req_seq_id': wallet_frz_params.get('req_seq_id', ''),
                'org_req_date': wallet_frz_params.get('req_date', ''),
                'org_sys_id': wallet_frz_result.get('sys_id', ''),
            },
        ]
}

# 调用钱包余额解冻
try:
    wallet_unfrz_result = BasePayClient.post_request('ssproxy.unFrzWalletBal', wallet_unfrz_params)
# 如果需要套用指定配置调用接口，请参考以下
# wallet_unfrz_result = BasePayClient.post_request('ssproxy.unFrzWalletBal', wallet_unfrz_params, 'merchantKey2')
except Exception as e:
    print(str(e))
    sys.exit()
sub_resp_code = wallet_unfrz_result.get('sub_resp_code', '')
if sub_resp_code == '00000000':
    print('钱包余额解冻处理成功')
else:
    print('钱包余额解冻处理失败:' + wallet_unfrz_result.get('sub_resp_desc', ''))























