"""
2021.5.20 create by kefeng.zheng
取现交易接口调用实例
"""
import sys

import os

# 得到当前根目录
o_path = os.getcwd() # 返回当前工作目录
sys.path.append(o_path) # 添加当前目录，当前目录为basepay_demo的上一级时可导入basepay_sdk
sys.path.append('..') # 添加上一级目录，当前目录为basepay_demo下时，可导入basepay_sdk

from basepay_sdk.basepay_client import BasePayClient
from basepay_sdk.basepay import BasePay

import logging
import json
import datetime
import time

# 商户配置初始化
from demo_constants import demo_constants
import init_merchant_config

# 调试模式，默认False关闭，打开后输出日志供联调排查问题
BasePay.debug = True
# 生产模式，默认为True生产环境
BasePay.prod_mode = True


# 取现参数配置
req_date = datetime.datetime.now().strftime('%Y%m%d')
now_datetime = datetime.datetime.now().strftime('%Y%m%d%H%M%S')
req_seq_id = now_datetime + "01234567890"
mer_ord_id = now_datetime + "1234";
request_param = {
    # 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
    "req_seq_id" : req_seq_id,
    # 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
    "req_date": req_date,
    # 系统号，由汇付分配
    "sys_id": demo_constants.DEMO_SYS_ID,
    # 商户订单号，需保证商户下唯一，推荐采用日期时间+几位流水号的形式，可与req_seq_id相同
    "mer_ord_id": mer_ord_id,
    # 分配商户号
    "huifu_id": demo_constants.DEMO_HUIFU_ID,
    # 取现卡序列号
    "token_no" : demo_constants.TOKEN_NO,
    # 取现金额
    "cash_amt":"0.01",
    # 入账类型（T0：当日到账；T1：T1次工作日到账；D1：次自然日到账；）
    "into_acct_date_type":"T1",
    # 风控信息
    # 注意，风控信息为JSON字符串
    "risk_check_info" : json.dumps({
        "riskMngInfo" : {
            "subTradeType" : "4300"
        },
        "ipAddr":"139.207.19.246"
    }),
    # 异步通知地址
    "notify_url":"virgo://http://www.vclinker.com",

}

# 调用取现接口
try:
	post_result = BasePayClient.post_request('toppas.enchashment', request_param)
	# 如果需要套用指定配置调用接口，请参考以下
	# post_result = BasePayClient.post_request('toppas.enchashment', request_param, 'merchantKey2')
except Exception as e:
	print(str(e))
	sys.exit()

sub_resp_code = post_result.get('sub_resp_code', '')

if (sub_resp_code == '00000000'):
	print('处理成功')
	print('交易状态：' + post_result.get('trans_stat', ''))
	# 交易状态处理中后续可调用取现查询接口获取终态
elif (sub_resp_code == '00000100'):
	print('处理中')
	print('交易状态：' + post_result.get('trans_stat', ''))
	# 交易状态处理中后续可调用取现查询接口获取终态
else:
	print ('处理失败:' + post_result.get('sub_resp_desc', ''))
	
time.sleep(30) # 休眠30秒

# 取现查询参数组装
req_date_query = datetime.datetime.now().strftime('%Y%m%d')
now_datetime_query = datetime.datetime.now().strftime('%Y%m%d%H%M%S')
req_seq_id_query = now_datetime_query + "01234567890"
query_params = {
	'sys_id' : post_result.get('sys_id', ''),
	'trans_req_date' : post_result.get('req_date', ''),
	'trans_mer_ord_id' : post_result.get('mer_ord_id', ''),
	'req_date' : req_date_query,
	'req_seq_id' : req_seq_id_query,
	'huifu_id' : request_param.get('huifu_id', '')
}
# 调用取现查询接口
try:
	query_result = BasePayClient.post_request('topqur.cashQuery', query_params)
	# 如果需要套用指定配置调用接口，请参考以下
	# query_result = BasePayClient.post_request('topqur.cashQuery', query_params, 'merchantKey2')
except Exception as e:
	print(str(e))
	sys.exit()
	
sub_resp_code = query_result.get('sub_resp_code', '')

if (sub_resp_code == '00000000'):
	print('取现查询处理成功')
	print('交易状态：' + query_result.get('trans_stat', ''))
elif (sub_resp_code == '00000100'):
	print('处理中')
	print('交易状态：' + query_result.get('trans_stat', ''))
else:
	print ('取现查询处理失败:' + query_result.get('sub_resp_desc', ''))
