"""
2021.5.20 create by kefeng.zheng
扫码交易接口调用实例
"""
import sys

import os

# 得到当前根目录
o_path = os.getcwd() # 返回当前工作目录
sys.path.append(o_path) # 添加当前目录，当前目录为basepay_demo的上一级时可导入basepay_sdk
sys.path.append('..') # 添加上一级目录，当前目录为basepay_demo下时，可导入basepay_sdk

from basepay_sdk.basepay_client import BasePayClient
from basepay_sdk.basepay import BasePay

import logging
import json
import datetime
import time

# 商户配置初始化
from demo_constants import demo_constants
import init_merchant_config

# 调试模式，默认False关闭，打开后输出日志供联调排查问题
BasePay.debug = True
# 生产模式，默认为True生产环境
BasePay.prod_mode = True


req_date = datetime.datetime.now().strftime('%Y%m%d')
now_datetime = datetime.datetime.now().strftime('%Y%m%d%H%M%S')
req_seq_id = now_datetime + "01234567890"
# mer_ord_id = now_datetime + "1234567890"
mer_ord_id = req_seq_id;
time_expire = (datetime.datetime.now() + datetime.timedelta(minutes=2)).strftime('%Y%m%d%H%M%S')
request_param = {
    # 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
    "req_seq_id" : req_seq_id,
    # 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
    "req_date": req_date,
    # 系统号，由汇付分配
    "sys_id": demo_constants.DEMO_SYS_ID,
    # 商户订单号，需保证商户下唯一，推荐采用日期时间+几位流水号的形式，可与req_seq_id相同
    "mer_ord_id": mer_ord_id,
    # 分配商户号
    "huifu_id": demo_constants.DEMO_HUIFU_ID,
    # 渠道号，若需使用自有渠道请联系业务对接人
    "bank_channel_no" : "",
    # 交易金额
    "trans_amt":"0.02",
    # 商品描述
    "goods_desc":"测试商品",
	# 付款二维码
    "auth_code" : '134609161977977902',
    # 设备信息
    "terminal_device_info": {
            "device_type":"4",
            "device_ip":"139.207.19.246"
     },
    # 风控信息
    # 注意，风控信息为JSON字符串
    "risk_check_info" : json.dumps({
        "riskMngInfo" : {
            "subTradeType" : "4300"
        },
        "ipAddr":"139.207.19.246"
    }),
    # 异步通知地址
    "notify_url":"virgo://http://www.vclinker.com",

    # 交易有效期
    "time_expire":time_expire,
    # 指定支付方式 是否禁止用户使用信用卡支付。默认不禁用，若禁止请填1
    "limit_pay":"1",
    # 延时标志 1为延迟 0为不延迟
    "is_delay_acct":"0",
    # 传入分帐遇到优惠的处理规则 1-按比例分 2-按顺序保障 3-只给交易商户
    "term_div_coupon_type":"3",
    # 分账串
    # 注意只有真实分账场景才需要传入分账串，请避免传入多个分账方为同一商户的分账串
    "acct_split_bunch":{
        "acct_infos" : [
            # 分账方1
            {
                'huifu_id':demo_constants.DEMO_HUIFU_ID,
                'div_amt':'0.01'
            },
            # 分账方2
            {
                "huifu_id":demo_constants.DEMO_DIV_HUIFU_ID,
                "div_amt":"0.01"
            }
        ]
    },
    # 商户私有域
    "mer_priv":"",
    # 微信扩展参数集合
    "wx_data":"",
    # 支付宝扩展参数集合
    "alipay_data":"",
    # 银联扩展参数集合
    "unionpay_data":"",
    # 手续费类型 01:标准费率线上,02:标准费率线下,03:非盈利费率,04:缴费费率,05:保险费率,06:行业活动费率,07:校园餐饮费率,08:K12中小幼费率
    # 不送时取业务入驻配置的默认费率
    "pay_scene":"02"
}

# 调用聚合反扫接口
try:
	post_result = BasePayClient.post_request('top.trans.authCodePay', request_param)
	# 如果需要套用指定配置调用接口，请参考以下
	# post_result = BasePayClient.post_request('top.trans.authCodePay', request_param, 'merchantKey2')
except Exception as e:
	print(str(e))
	sys.exit()

sub_resp_code = post_result.get('sub_resp_code', '')

if (sub_resp_code == '00000000'):
	print('处理成功')
	print('交易状态：' + post_result.get('trans_stat', ''))
	# 交易状态处理中后续可调用交易查询接口获取终态
elif (sub_resp_code == '00000100'):
	print('处理中')
	print('交易状态：' + post_result.get('trans_stat', ''))
	# 交易状态处理中后续可调用交易查询接口获取终态
else:
	print ('处理失败:' + post_result.get('sub_resp_desc', ''))
	
time.sleep(30) # 休眠30秒

# 交易查询参数组装
query_params = {
	'product_id' : post_result.get('product_id', ''),
	'req_date' : request_param.get('req_date', ''),
	'req_seq_id' : request_param.get('req_seq_id', ''),
	'huifu_id' : request_param.get('huifu_id', '')
}
# 调用交易查询接口
try:
	query_result = BasePayClient.post_request('topqur.transQuery', query_params)
	# 如果需要套用指定配置调用接口，请参考以下
	# query_result = BasePayClient.post_request('topqur.transQuery', query_params, 'merchantKey2')
except Exception as e:
	print(str(e))
	sys.exit()
	
sub_resp_code = query_result.get('sub_resp_code', '')

if (sub_resp_code == '00000000'):
	print('交易查询处理成功')
	print('交易状态：' + query_result.get('trans_stat', ''))
elif (sub_resp_code == '00000100'):
	print('处理中')
	print('交易状态：' + query_result.get('trans_stat', ''))
else:
	print ('查询处理失败:' + query_result.get('sub_resp_desc', ''))

now_datetime = datetime.datetime.now().strftime('%Y%m%d%H%M%S')
req_seq_id = now_datetime + "01234567890R"
mer_ord_id = req_seq_id;
refund_params = {
	'product_id' : post_result.get('product_id', ''),
	'req_date' : req_date,
	'req_seq_id' : req_seq_id,
	'mer_ord_id' : mer_ord_id,
	'sys_id' : request_param.get('sys_id', ''),
	'huifu_id' : request_param.get('huifu_id', ''),
	#分账串，原路径退回无需上送
	#"acct_split_bunch":{
	#"acct_infos" : [
	#	# 分账方1
	#	{
	#		'huifu_id':demo_constants.DEMO_HUIFU_ID,
	#		'div_amt':'0.01'
	#	},
	#	# 分账方2
	#	{
	#		"huifu_id":demo_constants.DEMO_DIV_HUIFU_ID,
	#		"div_amt":"0.01"
	#	}
	#]
	#},
	# 原交易日期
	'org_req_date' : request_param.get('req_date', ''),
	# 以下指定原交易的唯一标识，org_req_seq_id、hf_seq_id、party_order_id中3选1
	# 原交易请求流水号
	'org_req_seq_id' : request_param.get('req_seq_id', ''),
	# 退款金额
	'ord_amt' : '0.02',
	# 设备信息
	"terminal_device_info": {
		"device_type":"4",
		"device_ip":"139.207.19.246"
	},
	# 备注
	'mark' : '交易退货测试',
	# 商户私有扩展域
	"mer_priv" : "扩展域",
	# 风控信息
	# 注意，风控信息为JSON字符串
	"risk_check_info" : {
		"riskMngInfo" : {
			"subTradeType" : "4300"
		},
		"ipAddr":"139.207.19.246"
	},
	# 异步通知地址
	"notify_url":"virgo://http://www.vclinker.com"
}

# 调用交易退款接口
try:
	refund_result = BasePayClient.post_request('toprrc.refund', refund_params)
	# 如果需要套用指定配置调用接口，请参考以下
	# refund_result = BasePayClient.post_request('toprrc.refund', refund_params, 'merchantKey2')
except Exception as e:
	print(str(e))
	sys.exit()
	
sub_resp_code = refund_result.get('sub_resp_code', '')

if (sub_resp_code == '00000000'):
	print('退款处理成功')
	print('交易状态：' + refund_result.get('trans_stat', ''))
elif (sub_resp_code == '00000100'):
	print('退款处理中')
	print('交易状态：' + refund_result.get('trans_stat', ''))
else:
	print ('退款处理失败:' + refund_result.get('sub_resp_desc', ''))
	
# 退款查询参数组装
refund_query_params = {
	# 系统号
	'sys_id' : refund_params.get('sys_id', ''),
	# 退款商户号
	'huifu_id' : refund_result.get('huifu_id', ''),
	# 原始退款请求日期
	'req_date' : refund_result.get('req_date', ''),
	# 以下上送原退款的唯一标识、mer_ord_id、req_seq_id、hf_seq_id、out_ord_id可4选1
    # 原退款请求流水号
	'req_seq_id' : refund_result.get('req_seq_id', '')
}

# 调用交易退款查询接口
try:
	refund_query_result = BasePayClient.post_request('topqur.refundQuery', refund_query_params)
	# 如果需要套用指定配置调用接口，请参考以下
	# refund_query_result = BasePayClient.post_request('topqur.refundQuery', refund_query_params, 'merchantKey2')
except Exception as e:
	print(str(e))
	sys.exit()
	
sub_resp_code = refund_query_result.get('sub_resp_code', '')

if (sub_resp_code == '00000000'):
	print('退款查询处理成功')
	print('交易状态：' + refund_query_result.get('trans_stat', ''))
elif (sub_resp_code == '00000100'):
	print('处理中')
	print('交易状态：' + refund_query_result.get('trans_stat', ''))
else:
	print ('退款查询处理失败:' + refund_query_result.get('sub_resp_desc', ''))

# 获取银联用户标识实例
req_seq_id = now_datetime + "01234567890U"
union_user_id_params = {
	# 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
	"req_date" : req_date,
	# 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
	"req_seq_id" : req_seq_id,
	# 关单交易商户号
	"huifu_id" : demo_constants.DEMO_HUIFU_ID,
	# 分配系统号
	"sys_id" : demo_constants.DEMO_SYS_ID,
	# 用户授权码，需自行获取临时授权码
	# 获取临时用户授权时，请求地址 https://qr.95516.com/qrcGtwWeb-web/api/userAuthversion=1.0.0&redirectUrl=callbackUrl,回调回来时 callbackUrl 后面添加 userAuthCode 和 respCode 两个参数， respCode=00标识成功， userAuthCode 为后台获取 APP 用户信息的临时授权码。
	"user_auth_code" : "6j2MZY3YShmGFn4NHfQqeA==",
	# APP标识,不送默认CloudPay
	"app_up_identifier" : "CloudPay"
}

# 调用获取银联用户标识
try:
	union_user_result = BasePayClient.post_request('top.trans.getUserMark', union_user_id_params)
	# 如果需要套用指定配置调用接口，请参考以下
	# refund_query_result = BasePayClient.post_request('top.trans.getUserMark', union_user_id_params, 'merchantKey2')
except Exception as e:
	print(str(e))
	sys.exit()

union_user_id = union_user_result.get('user_id', '')
if union_user_id is None or union_user_id == '':
	print ('获取银联用户标识失败')
else:
	print ('获取银联用户标识成功，user_id=' + union_user_id)
