# -*- coding: utf-8 -*-
import base64

from Crypto.Hash import SHA256
from Crypto.PublicKey import RSA
from Crypto.Signature import pkcs1_15  # 加签验签模块


# sha1私钥加签
'''
def sha1_rsa_sign(private_key, message, charset):
    try:
        private_key = fill_private_key_marker(private_key)
        msg = message.encode(charset)
        private_key = RSA.importKey(private_key)
        # message做“哈希”处理，RSA签名这么要求的
        hash_obj = SHA1.new(msg)
        signature = pkcs1_15.new(private_key).sign(hash_obj)
        return True, base64.b64encode(signature).decode(charset)
    except Exception as ex:
        return False, str(ex)
'''

# sha256私钥加签
def sha256_rsa_sign(private_key, message, charset):
    try:
        private_key = fill_private_key_marker(private_key)
        msg = message.encode(charset)
        private_key = RSA.importKey(private_key)
        # message做“哈希”处理，RSA签名这么要求的
        hash_obj = SHA256.new(msg)
        signature = pkcs1_15.new(private_key).sign(hash_obj)
        return True, base64.b64encode(signature).decode(charset)
    except Exception as ex:
        return False, str(ex)

# sha1公钥验签
'''
def sha1_rsa_design(signature, message, my_rsa_public):
    my_rsa_public = fill_public_key_marker(my_rsa_public)
    message = message.encode("utf-8")
    public_key = RSA.importKey(my_rsa_public)
    # message做“哈希”处理，RSA签名这么要求的
    hash_obj = SHA1.new(message)
    try:
        pkcs1_15.new(public_key).verify(hash_obj, base64.b64decode(signature))
        return True, ''
    except (ValueError, TypeError) as ex:
        return False, str(ex)
'''

# sha256公钥验签
def sha256_rsa_design(signature, message, my_rsa_public):
    my_rsa_public = fill_public_key_marker(my_rsa_public)
    message = message.encode("utf-8")
    public_key = RSA.importKey(my_rsa_public)
    # message做“哈希”处理，RSA签名这么要求的
    hash_obj = SHA256.new(message)
    try:
        pkcs1_15.new(public_key).verify(hash_obj, base64.b64decode(signature))
        return True, ''
    except (ValueError, TypeError) as ex:
        return False, str(ex)

def add_start_end(key, start_marker, end_marker):
    if key.find(start_marker) < 0:
        key = start_marker + key
    if key.find(end_marker) < 0:
        key = key + end_marker
    return key


def fill_private_key_marker(private_key):
    return add_start_end(private_key, "-----BEGIN PRIVATE KEY-----\n", "\n-----END PRIVATE KEY-----")


def fill_public_key_marker(public_key):
    return add_start_end(public_key, "-----BEGIN PUBLIC KEY-----\n", "\n-----END PUBLIC KEY-----")
